@@ -19,7 +19,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 #{{{sub new
 sub new {
@@ -220,16 +220,20 @@ __END__
 
 =head1 NAME
 
-Authn - useful utility functions for general Authn functionality.
+Authn
 
 =head1 ABSTRACT
 
-Utility library providing useful utility functions for general Authn functionality.
+useful utility functions for general Authn functionality.
 
 =head1 USAGE
 
+use Apache::Sling::Authn;
+
 =head1 DESCRIPTION
 
+Utility library providing useful utility functions for general Authn functionality.
+
 =head1 REQUIRED ARGUMENTS
 
 None required.
@@ -252,6 +256,8 @@ None required.
 
 =head1 DEPENDENCIES
 
+LWP::UserAgent
+
 =head1 INCOMPATIBILITIES
 
 None known.
@@ -268,4 +274,4 @@ Daniel David Parry <perl@ddp.me.uk>
 
 LICENSE: http://dev.perl.org/licenses/artistic.html
 
-COPYRIGHT: Daniel David Parry <perl@ddp.me.uk>
+COPYRIGHT: (c) 2010 Daniel David Parry <perl@ddp.me.uk>
