@@ -14,7 +14,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 #{{{sub add_setup
 
@@ -178,11 +178,21 @@ __END__
 
 =head1 NAME
 
-ContentUtil - Utility library returning strings representing Rest queries that
-perform content operations in the system.
+ContentUtil
 
 =head1 ABSTRACT
 
+Utility library returning strings representing Rest queries that perform
+content operations in the system.
+
+=head1 METHODS
+
+=head1 USAGE
+
+use Apache::Sling::ContentUtil;
+
+=head1 DESCRIPTION
+
 ContentUtil perl library essentially provides the request strings needed to
 interact with content functionality exposed over the system rest interfaces.
 
@@ -192,12 +202,6 @@ result of performing the request.
 
 =head1 METHODS
 
-=head1 USAGE
-
-=head1 DESCRIPTION
-
-=head1 METHODS
-
 =head2 add_setup
 
 Returns a textual representation of the request needed to add content to the
@@ -297,4 +301,4 @@ Daniel David Parry <perl@ddp.me.uk>
 
 LICENSE: http://dev.perl.org/licenses/artistic.html
 
-COPYRIGHT: Daniel David Parry <perl@ddp.me.uk>
+COPYRIGHT: (c) 2010 Daniel David Parry <perl@ddp.me.uk>
