@@ -16,28 +16,10 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.08';
-
-=head1 NAME
-
-Request - useful utility functions for general Request functionality.
-
-=head1 ABSTRACT
-
-Utility library providing useful utility functions for general Request functionality.
-
-=cut
+our $VERSION = '0.09';
 
 #{{{sub string_to_request
 
-=pod
-
-=head2 string_to_request
-
-Function taking a string and converting to a GET or POST HTTP request.
-
-=cut
-
 sub string_to_request {
     my ( $string, $authn, $verbose, $log ) = @_;
     if ( !defined $string ) { croak 'No string defined to turn into request!'; }
@@ -118,16 +100,6 @@ sub string_to_request {
 
 #{{{sub request
 
-=pod
-
-=head2 request
-
-Function to actually issue an HTTP request given a suitable string
-representation of the request and an object which references a suitable LWP
-object.
-
-=cut
-
 sub request {
     my ( $object, $string ) = @_;
     if ( !defined $string ) { croak "No string defined to turn into request!"; }
@@ -154,14 +126,32 @@ __END__
 
 =head1 NAME
 
+Request
+
 =head1 ABSTRACT
 
+useful utility functions for general Request functionality.
+
 =head1 METHODS
 
+=head2 string_to_request
+
+Function taking a string and converting to a GET or POST HTTP request.
+
+=head2 request
+
+Function to actually issue an HTTP request given a suitable string
+representation of the request and an object which references a suitable LWP
+object.
+
 =head1 USAGE
 
+use Apache::Sling::Request;
+
 =head1 DESCRIPTION
 
+Utility library providing useful utility functions for general Request functionality.
+
 =head1 REQUIRED ARGUMENTS
 
 None required.
@@ -200,4 +190,4 @@ Daniel David Parry <perl@ddp.me.uk>
 
 LICENSE: http://dev.perl.org/licenses/artistic.html
 
-COPYRIGHT: Daniel David Parry <perl@ddp.me.uk>
+COPYRIGHT: (c) 2010 Daniel David Parry <perl@ddp.me.uk>
