@@ -17,29 +17,10 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.08';
-
-=head1 NAME
-
-User - user related functionality for Sling implemented over rest
-APIs.
-
-=head1 ABSTRACT
-
-Perl library providing a layer of abstraction to the REST user methods
-
-=cut
+our $VERSION = '0.09';
 
 #{{{sub new
 
-=pod
-
-=head2 new
-
-Create, set up, and return a User Agent.
-
-=cut
-
 sub new {
     my ( $class, $authn, $verbose, $log ) = @_;
     if ( !defined $authn ) { croak 'no authn provided!'; }
@@ -71,15 +52,15 @@ sub set_results {
 
 #{{{sub add
 sub add {
-    my ( $user, $actOnUser, $actOnPass, $properties ) = @_;
+    my ( $user, $act_on_user, $act_on_pass, $properties ) = @_;
     my $res = Apache::Sling::Request::request(
         \$user,
         Apache::Sling::UserUtil::add_setup(
-            $user->{'BaseURL'}, $actOnUser, $actOnPass, $properties
+            $user->{'BaseURL'}, $act_on_user, $act_on_pass, $properties
         )
     );
     my $success = Apache::Sling::UserUtil::add_eval($res);
-    my $message = "User: \"$actOnUser\" ";
+    my $message = "User: \"$act_on_user\" ";
     $message .= ( $success ? "added!" : "was not added!" );
     $user->set_results( "$message", $res );
     return $success;
@@ -89,10 +70,10 @@ sub add {
 
 #{{{sub add_from_file
 sub add_from_file {
-    my ( $user, $file, $forkId, $numberForks ) = @_;
-    my $csv           = Text::CSV->new();
-    my $count         = 0;
-    my $numberColumns = 0;
+    my ( $user, $file, $fork_id, $number_of_forks ) = @_;
+    my $csv               = Text::CSV->new();
+    my $count             = 0;
+    my $number_of_columns = 0;
     my @column_headings;
     if ( open my ($input), "<", $file ) {
         while (<$input>) {
@@ -115,27 +96,27 @@ sub add_from_file {
 "Second CSV column must be the user password, column heading must be \"password\". Found: \""
                           . $column_headings[0] . "\".\n";
                     }
-                    $numberColumns = @column_headings;
+                    $number_of_columns = @column_headings;
                 }
                 else {
                     croak "CSV broken, failed to parse line: "
                       . $csv->error_input;
                 }
             }
-            elsif ( $forkId == ( $count++ % $numberForks ) ) {
+            elsif ( $fork_id == ( $count++ % $number_of_forks ) ) {
                 my @properties;
                 if ( $csv->parse($_) ) {
                     my @columns      = $csv->fields();
                     my $columns_size = @columns;
 
            # Check row has same number of columns as there were column headings:
-                    if ( $columns_size != $numberColumns ) {
+                    if ( $columns_size != $number_of_columns ) {
                         croak
-"Found \"$columns_size\" columns. There should have been \"$numberColumns\".\nRow contents was: $_";
+"Found \"$columns_size\" columns. There should have been \"$number_of_columns\".\nRow contents was: $_";
                     }
                     my $id       = $columns[0];
                     my $password = $columns[1];
-                    for ( my $i = 2 ; $i < $numberColumns ; $i++ ) {
+                    for ( my $i = 2 ; $i < $number_of_columns ; $i++ ) {
                         my $value = $column_headings[$i] . "=" . $columns[$i];
                         push( @properties, $value );
                     }
@@ -157,16 +138,16 @@ sub add_from_file {
 
 #{{{sub change_password
 sub change_password {
-    my ( $user, $actOnUser, $actOnPass, $newPass, $newPassConfirm ) = @_;
+    my ( $user, $act_on_user, $act_on_pass, $new_pass, $new_pass_confirm ) = @_;
     my $res = Apache::Sling::Request::request(
         \$user,
         Apache::Sling::UserUtil::change_password_setup(
-            $user->{'BaseURL'}, $actOnUser, $actOnPass,
-            $newPass,           $newPassConfirm
+            $user->{'BaseURL'}, $act_on_user, $act_on_pass,
+            $new_pass,          $new_pass_confirm
         )
     );
     my $success = Apache::Sling::UserUtil::change_password_eval($res);
-    my $message = "User: \"$actOnUser\" ";
+    my $message = "User: \"$act_on_user\" ";
     $message .= ( $success ? "password changed!" : "password not changed!" );
     $user->set_results( "$message", $res );
     return $success;
@@ -176,12 +157,15 @@ sub change_password {
 
 #{{{sub del
 sub del {
-    my ( $user, $actOnUser ) = @_;
-    my $res = Apache::Sling::Request::request( \$user,
-        Apache::Sling::UserUtil::delete_setup( $user->{'BaseURL'}, $actOnUser )
+    my ( $user, $act_on_user ) = @_;
+    my $res = Apache::Sling::Request::request(
+        \$user,
+        Apache::Sling::UserUtil::delete_setup(
+            $user->{'BaseURL'}, $act_on_user
+        )
     );
     my $success = Apache::Sling::UserUtil::delete_eval($res);
-    my $message = "User: \"$actOnUser\" ";
+    my $message = "User: \"$act_on_user\" ";
     $message .= ( $success ? "deleted!" : "was not deleted!" );
     $user->set_results( "$message", $res );
     return $success;
@@ -191,12 +175,15 @@ sub del {
 
 #{{{sub check_exists
 sub check_exists {
-    my ( $user, $actOnUser ) = @_;
-    my $res = Apache::Sling::Request::request( \$user,
-        Apache::Sling::UserUtil::exists_setup( $user->{'BaseURL'}, $actOnUser )
+    my ( $user, $act_on_user ) = @_;
+    my $res = Apache::Sling::Request::request(
+        \$user,
+        Apache::Sling::UserUtil::exists_setup(
+            $user->{'BaseURL'}, $act_on_user
+        )
     );
     my $success = Apache::Sling::UserUtil::exists_eval($res);
-    my $message = "User \"$actOnUser\" ";
+    my $message = "User \"$act_on_user\" ";
     $message .= ( $success ? "exists!" : "does not exist!" );
     $user->set_results( "$message", $res );
     return $success;
@@ -211,10 +198,11 @@ sub me {
       Apache::Sling::Request::request( \$user,
         Apache::Sling::UserUtil::me_setup( $user->{'BaseURL'} ) );
     my $success = Apache::Sling::UserUtil::me_eval($res);
-    my $message =
-      (   $success
+    my $message = (
+          $success
         ? $$res->content
-        : "Problem fetching details for current user" );
+        : "Problem fetching details for current user"
+    );
     $user->set_results( "$message", $res );
     return $success;
 }
@@ -228,10 +216,11 @@ sub sites {
       Apache::Sling::Request::request( \$user,
         Apache::Sling::UserUtil::sites_setup( $user->{'BaseURL'} ) );
     my $success = Apache::Sling::UserUtil::sites_eval($res);
-    my $message =
-      (   $success
+    my $message = (
+          $success
         ? $$res->content
-        : "Problem fetching details for current user" );
+        : "Problem fetching details for current user"
+    );
     $user->set_results( "$message", $res );
     return $success;
 }
@@ -240,15 +229,15 @@ sub sites {
 
 #{{{sub update
 sub update {
-    my ( $user, $actOnUser, $properties ) = @_;
+    my ( $user, $act_on_user, $properties ) = @_;
     my $res = Apache::Sling::Request::request(
         \$user,
         Apache::Sling::UserUtil::update_setup(
-            $user->{'BaseURL'}, $actOnUser, $properties
+            $user->{'BaseURL'}, $act_on_user, $properties
         )
     );
     my $success = Apache::Sling::UserUtil::update_eval($res);
-    my $message = "User: \"$actOnUser\" ";
+    my $message = "User: \"$act_on_user\" ";
     $message .= ( $success ? "updated!" : "was not updated!" );
     $user->set_results( "$message", $res );
     return $success;
@@ -258,13 +247,16 @@ sub update {
 
 #{{{sub view
 sub view {
-    my ( $user, $actOnUser ) = @_;
-    my $res = Apache::Sling::Request::request( \$user,
-        Apache::Sling::UserUtil::exists_setup( $user->{'BaseURL'}, $actOnUser )
+    my ( $user, $act_on_user ) = @_;
+    my $res = Apache::Sling::Request::request(
+        \$user,
+        Apache::Sling::UserUtil::exists_setup(
+            $user->{'BaseURL'}, $act_on_user
+        )
     );
     my $success = Apache::Sling::UserUtil::exists_eval($res);
     my $message =
-      ( $success ? $$res->content : "Problem viewing user: \"$actOnUser\"" );
+      ( $success ? $$res->content : "Problem viewing user: \"$act_on_user\"" );
     $user->set_results( "$message", $res );
     return $success;
 }
@@ -277,14 +269,26 @@ __END__
 
 =head1 NAME
 
+User
+
 =head1 ABSTRACT
 
+user related functionality for Sling implemented over rest APIs.
+
 =head1 METHODS
 
+=head2 new
+
+Create, set up, and return a User Agent.
+
 =head1 USAGE
 
+use Apache::Sling::User;
+
 =head1 DESCRIPTION
 
+Perl library providing a layer of abstraction to the REST user methods
+
 =head1 REQUIRED ARGUMENTS
 
 None required.
@@ -323,4 +327,4 @@ Daniel David Parry <perl@ddp.me.uk>
 
 LICENSE: http://dev.perl.org/licenses/artistic.html
 
-COPYRIGHT: Daniel David Parry <perl@ddp.me.uk>
+COPYRIGHT: (c) 2010 Daniel David Parry <perl@ddp.me.uk>
